pub struct OneLog {Show 13 fields
pub data: Vec<String>,
pub timestamp: i64,
pub layer: Layer,
pub src: SourceLog,
pub idx: u64,
pub dir: Option<String>,
pub ue_id: Option<u64>,
pub cell: Option<u64>,
pub rnti: Option<u64>,
pub frame: Option<u16>,
pub slot: Option<u8>,
pub channel: Option<String>,
pub level: Option<u8>,
}Expand description
Data structure to store the log.
Fields
data: Vec<String>Each item is a string representing a line of log.
timestamp: i64Milliseconds since January 1st 1970.
layer: Layerlog layer
src: SourceLogSource of the log.
idx: u64index
dir: Option<String>Direction (UL/DL/TO/FROM)
ue_id: Option<u64>UE identifier
cell: Option<u64>Cell identifier
rnti: Option<u64>RNTI
frame: Option<u16>Frame number (PHY)
slot: Option<u8>Slot number (PHY)
channel: Option<String>Channel name (PHY: PDCCH, PDSCH, etc.)
level: Option<u8>Log level
Implementations
Sourceimpl OneLog
impl OneLog
Sourcepub fn extract_hexe(&self) -> Result<Vec<u8>, TramexError>
pub fn extract_hexe(&self) -> Result<Vec<u8>, TramexError>
Extract the hexadecimal representation of the log.
Errors
Returns a TramexError if the hexe representation could not be extracted.
Sourcepub fn extract_canal_msg(&self) -> Option<String>
pub fn extract_canal_msg(&self) -> Option<String>
Extract the canal message of the log.
Sourcepub fn extract_data(&self) -> Result<Trace, TramexError>
pub fn extract_data(&self) -> Result<Trace, TramexError>
Extract the data of the log using the unified LayerParser pipeline.
Errors
Returns a TramexError if the data could not be extracted.